@@ -363,7 +363,7 @@ def addModuleParam(module, parameterName, parameterValue, allowOverwrite=True, h
 	"""
 	Add value to the param string in the jos_components table for the specified component.
 	"""
-	paramDict = _buildPluginDictionary(module,hubName)
+	paramDict = _buildModuleDictionary(module,hubName)
 
 	if allowOverwrite:
 		paramDict[parameterName] = parameterValue
